# Geographies
A list of every geography object saved in the database.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.
### Name:
A representation name for the selected geography. Consists of its geography type (continent, country, state or city), the geography's name (e.g. Hamburg) and in the case of states and cities the alpha 3 code of its parent country in brackets (e.g. DEU).
### Parent:
The representation name of the geography's parent. Geography objects are ordered like this: Continent > Country > State > City. As a result, continents have no parent. Hover over the name to display the parent's name, their parent object and alpha 3 country code. Column can be ordered by (non-representation-) name.
### Alpha 2 Country Code:
The alpha 2 country code for the geography object's parent country. Thus, continents have no country codes.
### Alpha 3 Country Code:
The alpha 3 country code for the geography object's parent country.

## Search Field:
Typing in the search field allows to filter the geography objects by name.
